/*
 * Copyright 2007 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.google.test.metric.method.op.stack;

import java.util.List;

import com.google.test.metric.JavaType;
import com.google.test.metric.Type;
import com.google.test.metric.Variable;
import com.google.test.metric.method.Constant;

public class Convert extends StackOperation {

  private final Type from;
  private final Type to;

  public Convert(int lineNumber, Type from, Type to) {
    super(lineNumber);
    this.from = from;
    this.to = to;
  }

  @Override
  public int getOperatorCount() {
    return JavaType.isDoubleSlot(from) ? 2 : 1;
  }

  @Override
  public List<Variable> apply(List<Variable> input) {
    Variable variable = input.get(0);
    return list(new Constant(variable.getName(), to));
  }

  @Override
  public String toString() {
    return "convert " + from + " -> " + to;
  }

}
