/*
 * Copyright 2007 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.google.test.metric.report;

import java.io.IOException;
import java.io.OutputStream;
import java.util.Properties;

import com.google.test.metric.ClassCost;
import com.google.test.metric.CostModel;

/**
 * Write out the classes and their metrics in a Java properties file format.
 * @author alexeagle@google.com (Alex Eagle)
 *
 */
public class PropertiesReportGenerator implements ReportGenerator {

  private final Properties properties = new Properties();
  private final OutputStream out;
  private final CostModel costModel;

  /**
   * @param out where the report should be written
   */
  public PropertiesReportGenerator(OutputStream out, CostModel costModel) {
    this.out = out;
    this.costModel = costModel;
  }

  public void addClassCost(ClassCost classCost) {
    properties.setProperty(classCost.getClassName(), String.valueOf(costModel.computeClass(classCost)));
  }

  public void printFooter() {
    try {
      properties.store(out, "Metrics generated by Testability Explorer");
    } catch (IOException e) {
      throw new RuntimeException(e);
    }
  }

  public void printHeader() {
    // Nothing to do
  }

}
